#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IDIVFLOOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IDIVFLOOR_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/scalar/idivfloor.hpp>

#endif
